package org.javabuilders.swing.jide;

import org.javabuilders.BuilderConfig;
import org.javabuilders.swing.SwingBuilder;

import com.jidesoft.dialog.BannerPanel;
import com.jidesoft.dialog.ButtonPanel;
import com.jidesoft.dialog.JideOptionPane;
import com.jidesoft.dialog.MultiplePageDialog;
import com.jidesoft.dialog.MultiplePageDialogPane;
import com.jidesoft.dialog.ScrollableButtonPanel;
import com.jidesoft.dialog.StandardDialog;
import com.jidesoft.dialog.StandardDialogPane;
import com.jidesoft.hints.FileIntelliHints;
import com.jidesoft.hints.IntelliHints;
import com.jidesoft.hints.ListDataIntelliHints;
import com.jidesoft.popup.JidePopup;
import com.jidesoft.spinner.DateSpinner;
import com.jidesoft.spinner.PointSpinner;
import com.jidesoft.swing.AutoCompletionComboBox;
import com.jidesoft.swing.AutoResizingTextArea;
import com.jidesoft.swing.Calculator;
import com.jidesoft.swing.CheckBoxList;
import com.jidesoft.swing.CheckBoxListWithSelectable;
import com.jidesoft.swing.CheckBoxTree;
import com.jidesoft.swing.ClickThroughLabel;
import com.jidesoft.swing.ClickThroughStyledLabel;
import com.jidesoft.swing.ComboBoxSearchable;
import com.jidesoft.swing.ContentContainer;
import com.jidesoft.swing.Contour;
import com.jidesoft.swing.CornerScroller;
import com.jidesoft.swing.DefaultOverlayable;
import com.jidesoft.swing.DefaultSelectable;
import com.jidesoft.swing.FolderChooser;
import com.jidesoft.swing.Gripper;
import com.jidesoft.swing.HeaderBox;
import com.jidesoft.swing.HeavyweightWrapper;
import com.jidesoft.swing.InfiniteProgressPanel;
import com.jidesoft.swing.JCellRendererPane;
import com.jidesoft.swing.JideButton;
import com.jidesoft.swing.JideComboBox;
import com.jidesoft.swing.JideLabel;
import com.jidesoft.swing.JideMenu;
import com.jidesoft.swing.JidePopupMenu;
import com.jidesoft.swing.JideScrollPane;
import com.jidesoft.swing.JideSplitButton;
import com.jidesoft.swing.JideSplitPane;
import com.jidesoft.swing.JideSplitPaneDivider;
import com.jidesoft.swing.JideTabbedPane;
import com.jidesoft.swing.JideTitledBorder;
import com.jidesoft.swing.JideToggleButton;
import com.jidesoft.swing.JideToggleSplitButton;
import com.jidesoft.swing.LabeledTextField;
import com.jidesoft.swing.MeterProgressBar;
import com.jidesoft.swing.MultilineLabel;
import com.jidesoft.swing.NullButton;
import com.jidesoft.swing.NullCheckBox;
import com.jidesoft.swing.NullJideButton;
import com.jidesoft.swing.NullLabel;
import com.jidesoft.swing.NullPanel;
import com.jidesoft.swing.NullRadioButton;
import com.jidesoft.swing.NullTristateCheckBox;
import com.jidesoft.swing.OverlayCheckBox;
import com.jidesoft.swing.OverlayComboBox;
import com.jidesoft.swing.OverlayRadioButton;
import com.jidesoft.swing.OverlayTextArea;
import com.jidesoft.swing.OverlayTextField;
import com.jidesoft.swing.PaintPanel;
import com.jidesoft.swing.PartialEtchedBorder;
import com.jidesoft.swing.PartialGradientLineBorder;
import com.jidesoft.swing.PartialLineBorder;
import com.jidesoft.swing.PopupWindow;
import com.jidesoft.swing.RangeSlider;
import com.jidesoft.swing.ResizableDialog;
import com.jidesoft.swing.ResizableFrame;
import com.jidesoft.swing.ResizablePanel;
import com.jidesoft.swing.ResizableWindow;
import com.jidesoft.swing.SearchableBar;
import com.jidesoft.swing.SimpleScrollPane;
import com.jidesoft.swing.SplitButtonGroup;
import com.jidesoft.swing.StyledLabel;
import com.jidesoft.swing.TableSearchable;
import com.jidesoft.swing.TextComponentSearchable;
import com.jidesoft.swing.TitledSeparator;
import com.jidesoft.swing.TreeSearchable;
import com.jidesoft.swing.TristateCheckBox;

/**
 * Configures the JIDE-OSS components into the Java SwingBuilder
 * 
 * @author Jacek Furmankiewicz
 */
public final class SwingJideOssConfig
{
    
    
    /**
     * Constructor.
     * 
     */
    private SwingJideOssConfig()
    {
        // Helper Class
    }

    /**
     * Registers SwingX components into the default SwingBuilder
     */
    public static void register()
    {
        register(SwingBuilder.getConfig());
    }
    
    /**
     * Registers SwingX components into the specified BuilderConfig
     * 
     * @param config
     *            Builder configuration
     */
    public static void register(BuilderConfig config)
    {
        
        // visual components
        config.addType(BannerPanel.class,
                       ButtonPanel.class,
                       JideOptionPane.class,
                       MultiplePageDialog.class,
                       MultiplePageDialogPane.class,
                       ScrollableButtonPanel.class,
                       StandardDialog.class,
                       StandardDialogPane.class,
                       FileIntelliHints.class,
                       IntelliHints.class,
                       ListDataIntelliHints.class,
                       JidePopup.class,
                       DateSpinner.class,
                       PointSpinner.class,
                       AutoCompletionComboBox.class,
                       AutoResizingTextArea.class,
                       Calculator.class,
                       CheckBoxList.class,
                       CheckBoxListWithSelectable.class,
                       CheckBoxTree.class,
                       ClickThroughLabel.class,
                       ClickThroughStyledLabel.class,
                       ComboBoxSearchable.class,
                       ContentContainer.class,
                       Contour.class,
                       CornerScroller.class,
                       DefaultOverlayable.class,
                       DefaultSelectable.class,
                       FolderChooser.class,
                       Gripper.class,
                       HeaderBox.class,
                       HeavyweightWrapper.class,
                       InfiniteProgressPanel.class,
                       JCellRendererPane.class,
                       JideButton.class,
                       JideComboBox.class,
                       JideMenu.class,
                       JidePopupMenu.class,
                       JideScrollPane.class,
                       JideSplitButton.class,
                       JideSplitPane.class,
                       JideSplitPaneDivider.class,
                       JideTabbedPane.class,
                       JideTitledBorder.class,
                       JideToggleButton.class,
                       JideToggleSplitButton.class,
                       LabeledTextField.class,
                       MeterProgressBar.class,
                       MultilineLabel.class,
                       NullButton.class,
                       NullCheckBox.class,
                       NullJideButton.class,
                       NullLabel.class,
                       NullPanel.class,
                       NullRadioButton.class,
                       NullTristateCheckBox.class,
                       OverlayCheckBox.class,
                       OverlayComboBox.class,
                       OverlayRadioButton.class,
                       OverlayTextArea.class,
                       OverlayTextField.class,
                       PaintPanel.class,
                       PartialEtchedBorder.class,
                       PartialGradientLineBorder.class,
                       PartialLineBorder.class,
                       PopupWindow.class,
                       RangeSlider.class,
                       ResizableDialog.class,
                       ResizableFrame.class,
                       ResizablePanel.class,
                       ResizableWindow.class,
                       SearchableBar.class,
                       SimpleScrollPane.class,
                       SplitButtonGroup.class,
                       StyledLabel.class,
                       TableSearchable.class,
                       TextComponentSearchable.class,
                       TitledSeparator.class,
                       TreeSearchable.class,
                       TristateCheckBox.class,
                       JideLabel.class);
        
    }
}
